	
	// 饼图
	function initPieChart(options) {
		//设置全局等宽字体，方便截取
	    Highcharts.setOptions({
	        chart: {
	            style: {
	                fontFamily: '宋体,tahoma,arial,"Hiragino Sans GB",sans-serif'
	            }
	        }
	    });

		if (!options) {
			return;
		}
		
		var defaults = { 
				id: 'J_ChartWrap',
				title: '',
				titleMargin: 15,	//标题下边距
				marginLeft: -180,	//饼图位置
				backgroundColor: '#FFF',
				unit: '个',
				series: [{
					data: options.data
				}],
				legend: {
					backgroundColor: '#FFF',
					x: 250		//图例坐标
				},
				pie: {
					size: 180	//饼图尺寸
				},
				maxlength: 16,	//名称字节限制
				// digits: 2,   总数的小数位数：当统计的值可能为浮点数时设置该值，避免浮点数运算BUG。
				colors: ['#68bc31', '#2091cf', '#af4e96', '#da5430', '#fee074', '#bfbfbf', '#f28f43', '#77a1e5', '#c42525', '#a6c96a',
				         '#4572A7', '#AA4643', '#89A54E', '#80699B', '#3D96AE', '#DB843D', '#92A8CD', '#A47D7C', '#B5CA92']
		};
		$.extend(defaults, options);
		var sum = 0;
		if ( options.allSum ) {
			sum = options.allSum;
		} else {
			data = options.data;
			for (var i=0; i<data.length; i++) {
				var item = data[i];
				sum += item[item.length -1];
			}
		}
		if ( defaults.digits ) {
			sum = sum.toFixed( defaults.digits );
		}
		//其他颜色默认值
		var labelColor = '#636363', 			//标签文字
			connectorColor = '#636363',			//连接线
			legendColor = '#274b6d',			//图例文字
			legendHighlightColor = '#1785e6',	//图例文字高亮
			legendTitleColor = '#006EB6';		//图例标题
		
		// 检查统计数量是否为0，如果为0则不绘图，且把绘图容器隐藏起来。
		if (sum <= 0) {
			$('#'+ defaults.id).hide();
			return false;
		}
		
		$('#'+ defaults.id).highcharts({
			chart: {
                type: 'pie',
                width: defaults.width,
                marginLeft: defaults.marginLeft,
                backgroundColor: defaults.backgroundColor
            },
            // 标题
            title: {
                text: defaults.title,
                margin: defaults.titleMargin
            },
            // 图形提示
            tooltip: {
            	formatter: function() {
            		return substrlen( this.point.name, 100 ) + '<br/><span style="color:#adadad">\u5171</span>: <b>' + this.y + '</b><span style="color:#adadad">' + defaults.unit
            				+ ', \u5360\u603b\u6570</span>: <b>' + this.percentage.toFixed(0) + '%</b>';
            	}
            	//pointFormat: '<span style="color:#adadad">\u5171</span>: <b>{point.y}</b><span style="color:#adadad">' + defaults.unit + ', \u5360\u603b\u6570</span>: <b>{point.percentage:.0f}%</b>'
            },
            // 百分比
            plotOptions: {
                pie: {
                	size: defaults.pie.size,
                    allowPointSelect: true,
                    showInLegend: true,
                    cursor: 'pointer',
                    dataLabels: {
                        enabled: true,
                        color: labelColor,
                        connectorColor: connectorColor,
                        connectorWidth: 2,
                        style: { fontSize: '12px' },
                        //format: '{point.name}: {point.percentage:.0f} %'
                        formatter: function() {
                    		return substrlen( this.point.name, defaults.maxlength ) + '：' + this.percentage.toFixed(0) + '%';
                    	}
                    },
                    point: {
                    	events: {
	                    	mouseOver: function(){
                        		$(this.legendItem.element).css('fill', legendHighlightColor);
		                    },
		                    mouseOut: function(){
		                    	$(this.legendItem.element).css('fill', legendColor);
		                    }
	                    }
                    }
            	}
            },
            // 图例
            legend: {
            	layout: 'vertical',
            	align: 'center',
                verticalAlign: 'middle',
                itemMarginBottom: 8,
                backgroundColor: defaults.legend.backgroundColor,
                x: defaults.legend.x,
                y: 0,
                padding: 5,
                maxHeight: 238,
                itemStyle: {
            		color: legendColor
            	},
                itemHoverStyle: {
            		color: legendHighlightColor
            	},
                title: {
            		text: options.itemName + '总数：' + sum + defaults.unit,
            		style: {
            			fontWeight: 'normal',
            			color: legendTitleColor
            		}
            	},
            	//labelFormat:  '{name}：{y}' + defaults.unit + '，{percentage:.0f} %',
            	labelFormatter: function() {
            		return substrlen( this.name, defaults.maxlength ) + '：' + this.y + defaults.unit + '，' + this.percentage.toFixed(0) + '%';
            	},
            	draggable: true		//图例可移动
            },
			// 数据
			series: defaults.series,
			// 颜色
			colors: defaults.colors,
			// 导出
            exporting: {
	        	 enabled: false
	         },
	         // 商标
	         credits: {
	        	 enabled: false
	         }
		}, function( chart ) {
	        $(chart.legend.allItems).each(function( i, e ) {
	            e.legendGroup.on('click',function() {
	                e.select( !e.selected );
	                return false;
	            });
	        });
		});
	}

	// 柱图
	function initColumnChart(options) {
		if (!options) {
			return;
		}
		
		var data = options.data,
			categories = [],
			sum = 0;
		for (var i=0; i<data.length; i++) {
			var item = data[i];
			categories.push(item[0]);
			sum += item[item.length -1];
		}
		
		var defaults = { 
				id: 'J_ChartWrap',
				height: options.height,
				title: '',
				categories: categories,
				series: formatColumnSeries(options.data, options.name),
				colors: ['#910000', '#3366cc', '#adadad',  '#2f7ed8',  '#1aadce', '#492970', '#f28f43', '#77a1e5', '#c42525', '#a6c96a']
		};
		$.extend(defaults, options);
		
		// 检查统计数量是否为0，如果为0则不绘图，且把绘图容器隐藏起来。
		if (sum <= 0) {
			$('#'+ defaults.id).hide();
			return false;
		}
		
		$('#'+ defaults.id).highcharts({
			chart: {
                type: 'column',
                height: defaults.height
            },
            // 标题
            title: {
                text: defaults.title
            },
			// 横坐标
			xAxis: {
				categories:  defaults.categories,
				labels: {
					y: 20
				}
			},
			// 纵坐标
			yAxis: {
				allowDecimals: false,
				title: {
					text: ''
				}
			},
			// 图例说明
			legend: {
				align: 'right',
				verticalAlign: 'top',
				x: -10,
				y: -10,
				floating: true,
				borderWidth: 1,
				backgroundColor: '#FFFFFF',
				shadow: true
			},
			// 图形提示
			tooltip: {
				pointFormat: '<span style="color:{series.color}">{series.name}</span>: <b style="color:{series.color};font-weight:bold;">{point.y}</b><br/>'
			},
			// 数据
			series: defaults.series,
			// 颜色
			colors: defaults.colors,
			// 导出
            exporting: {
	        	 enabled: false
	         },
	         // 商标
	         credits: {
	        	 enabled: false
	         }
		});
	}
	
	/**
	 * 格式化柱图的categories
	 * @param data：[ ['categoryName', num, ...], ... ]
	 * @returns ['categoryName', ...]
	 */
	function formatColumnCategories(data) {
		var categories = [];
		for (var i=0; i<data.length; i++) {
			categories.push(data[i][0]);
		}
		return categories;
	}
	
	/**
	 * 格式化柱图的series
	 * @param data：[ ['categoryName', num, ...], ... ]
	 * @param name：['seriesName', ... ]
	 * @returns [{ name: 'seriesName', data：[num, ...]}, ...]
	 */
	function formatColumnSeries(data, name) {
		var series = [];
		for (var i=0; i<name.length; i++) {
			var temp = [];
			for (var j=0; j<data.length; j++) {
				temp.push(data[j][i+1]);
			}
			
			series.push({
				name: name[i],
				data: temp
			});
		}
		return series;
	}

	function initLineChart(options) {
		var data = [], name = [];
		if ( options.series1 ) {
			data.push([ options.domain]);
			name.push([ options.series1]);
		}
		if ( options.series2 ) {
			data.push([ options.user]);
			name.push([ options.series2]);
		}
		if ( options.series3 ) {
			data.push([ options.allUser]);
			name.push([ options.series3]);
		}
	      chart = new Highcharts.Chart({
	         chart: {
	            renderTo: 'J_container',
	            type: 'line',
            	backgroundColor: '#FFF'
	         },
	         title: {
	            text: ''
	         },
	         xAxis: {
	            categories: options.time,
	            labels: { 
              rotation: -45,  
              align: 'right'  
          } 
	         },
	         yAxis: {
	            title: {
	               text:  options.Y_title
	            },
	         	min: 0
	         },
	         tooltip: {
	             valueSuffix: options.unit
	         },
	         credits: {
	        	 enabled: false
	         },
	         series: formatLineChartSeries( data, name ),
	      });
      }
	
	 function formatLineChartSeries ( data, name ) {
		var series = [];
		for (var i=0; i<name.length; i++) {
			series.push({
				name: name[i]['0'],
				data: data[i]['0']
			});
		}
		return series;
	}
/**
 * Highcharts 插件：可移动图例
 */
(function (H) {
    var addEvent = H.addEvent;
    
    H.wrap(H.Chart.prototype, 'init', function (proceed) {
        proceed.apply(this, Array.prototype.slice.call(arguments, 1));
        
        var chart = this, 
            legend = chart.legend,
            box = legend.box,
            title = legend.title,
            options = legend.options,
            isDragging,
            downX,
            downY,
            optionsX,
            optionsY,
            currentX,
            currentY,
            initFunc = function (e) {
                e = chart.pointer.normalize(e);
                downX = e.chartX;
                downY = e.chartY;
                optionsX = options.x;
                optionsY = options.y;
                currentX = legend.group.attr('translateX');
                currentY = legend.group.attr('translateY');
                isDragging = true;
                xCanMove = false;
                yCanMove = false;
            };

        if (options.draggable) {
        	//空白处或标题可移动
            box.css({ cursor: 'move' });
            addEvent(box.element, 'mousedown', initFunc);
            
            if ( title ) {
            	title.css({ cursor: 'move' });
            	addEvent(title.element, 'mousedown', initFunc);
            }

            addEvent(chart.container, 'mousemove', function (e) {
                if (isDragging) {
                    e = chart.pointer.normalize(e);
                    var draggedX = e.chartX - downX,
                        draggedY = e.chartY - downY;
                    
                    // Do the move is we're inside the chart
                    if (currentX + draggedX > 0 && currentX + draggedX + legend.legendWidth < chart.chartWidth ) {
                    	options.x = optionsX + draggedX;
                    	xCanMove = true;
                    }
                    if (currentY + draggedY > 0 && currentY + draggedY + legend.legendHeight < chart.chartHeight ) {
                    	options.y = optionsY + draggedY;
                    	yCanMove = true;
                    }
                    if (xCanMove || yCanMove) {
                        legend.group.placed = false; // prevent animation
                        legend.group.align(H.extend({
                            width: legend.legendWidth,
                            height: legend.legendHeight
                        }, options), true, 'spacingBox');
                    }
                    if (chart.pointer.selectionMarker) {
                        chart.pointer.selectionMarker = chart.pointer.selectionMarker.destroy();
                    }
                    
                }
            });
            addEvent(document, 'mouseup', function () {
                isDragging = false;
            });
        }
    });
}(Highcharts));

// 按字节截取字符串长度，中文算两个
function substrlen( str, maxlen ) {
	var code, res, suffix;
	for ( i = 0; i < maxlen; i++ ) {
		code = str.charCodeAt(i);
		
		if ( isNaN(code) ) return str;
		
		if ( code > 255 ) {
			maxlen--;
		}
	}
	res = str.substr(0, maxlen);
	suffix = res == str ? '' : '...';
	return res + suffix;
}
