appcan.define("locStore",function($,exports,module){
    function LocStore(option){
        appcan.extend(this,appcan.eventEmitter);
        var self = this;
        option = option || {};
        self.option = $.extend({
            dbName:'zhoudaoapp',
            dbVersion:'1.0',
            storeName:'homeImg',
            nameIndex:'nameIndex',
            db:null
        },option,true);
    }
    var indexedDB = window.indexedDB || window.webkitIndexedDB ||window.mozIndexedDB;
    LocStore.prototype = {
        onerror:function(e){
            console.log(e);
        },
        open:function(callback){
            var self = this;
            var request = indexedDB.open(self.option.dbName,self.option.dbVersion);
            request.onsuccess=function(e){
                self.option.db = e.target.result;
                callback(null);
            };
            request.onerror = function(e){
                callback(e);
                console.log(e);
            };
            request.onupgradeneeded = function(e){
                var db = e.target.result;
                if(!db.objectStoreNames.contains(self.option.storeName)){
                    var store = db.createObjectStore(self.option.storeName,{keyPath:"id"});
                    store.createIndex(self.option.nameIndex,'name',{unique:true});
                }
                console.log('db version changed to '+self.option.dbVersion);
            }
        },
        init:function(arr,cb){
            var self = this;
            if(appcan.isFunction(arr)){
                cb = arr;
                arr = [];
            }
            async.waterfall([
                function(callback){
                    callback(null,null);
                },
                function(arg1,callback){
                    //
                    self.dataList(function(list){
                        //console.log(arr);
                        if(list.length == 0 && arr.length>0){
                            var datas = [];
                            for(var i=1;i<=arr.length;i++){
                                var temp={id:arr[i-1].id,name:arr[i-1].type};
                                datas.push(temp);
                            }
                            //console.log(temp);
                            async.each(datas,function(item,cback){
                                console.log(item);
                                self.addData(item,function(r){
                                    cback();
                                });
                            },function(err){
                                callback(null,'done');
                            });
                        }else{
                            callback(null,'done');
                        }
                    });
                }
            ],function(err,result){
                self.dataList(function(data){
                    cb(data);
                });
            });
        },
        close:function(){
            var self = this;
            self.option.db.close();
        },
        deleteDB:function(name){
            indexedDB.deleteDatabase(name);
        },
        addData:function(data,callback){
            var self = this;
            var transaction = self.option.db.transaction(self.option.storeName,'readwrite');
            var store = transaction.objectStore(self.option.storeName);
            var request = store.add(data);
            //新增这里的onsuccess不好使
            //request.onsuccess=function(){
                callback();
            //}
        },
        getDataByKey:function(key,callback){
            var self = this;
            var transaction = self.option.db.transaction(self.option.storeName,'readwrite');
            var store = transaction.objectStore(self.option.storeName);
            var request = store.get(key);
            request.onsuccess = function(e){
                callback(e.target.result);
            };
        },
        updateDataByKey:function(key,data,callback){
            var self = this;
            var transaction = self.option.db.transaction(self.option.storeName,'readwrite');
            var store = transaction.objectStore(self.option.storeName);
            var request = store.get(key);
            request.onsuccess = function(e){
                var oldData = e.target.result;
                $.extend(oldData,data);
                store.put(oldData);
                callback();
            };
        },
        deleteDataByKey:function(key,callback){
            var self = this;
            var transaction = self.option.db.transaction(self.option.storeName,'readwrite');
            var store = transaction.objectStore(self.option.storeName);
            //key必须是数字，key是homeImg数据库中的key
            var request = store.delete(parseInt(key));
            request.onsuccess=function(){
                callback();
            }
        },
        clearObjectStore:function(){
            var self = this;
            var transaction =self.option.db.transaction(self.option.storeName,'readwrite');
            var store = transaction.objectStore(self.option.storeName);
            store.clear();
        },
        dataList:function(callback){
            try{
                var self = this;
                var transaction = self.option.db.transaction(self.option.storeName,'readwrite');
                var store = transaction.objectStore(self.option.storeName);
                var index = store.index(self.option.nameIndex);
                var request = index.openCursor(null,IDBCursor.next);
                var data = [];
                request.onsuccess=function(e){
                    var cursor = e.target.result;
                    if(cursor){
                        data.push(cursor.value);
                        cursor.continue();
                    }else{
                        callback(data);
                    }
                },
                request.onerror=function(e){
                    console.log(e);
                }
            }catch(e){
                console.log(e);
            }
        }
    };
    module.exports = function(option){
        return new LocStore(option);
    }
});
